@@ -1,19 +1,19 @@
 "InvertQ" <- 
 function(coef){
- stopifnot(class(coef)=="numeric"||class(coef)=="matrix"||(class(coef)=="array" && (dim(coef)[1]==dim(coef)[2])))
-     if (class(coef) == "numeric")
+stopifnot((inherits(coef,"numeric")||inherits(coef,"matrix")||inherits(coef,"array")&&(dim(coef)[1]==dim(coef)[2])))
+     if (inherits(coef,"numeric"))
        coef <- array(coef,dim=c(1,1,length(coef)))
-     if (class(coef) == "matrix")
+     if (inherits(coef,"matrix"))
        coef <- array(coef,dim=c(NROW(coef),NROW(coef),1))
      k <- dim(coef)[1]
-     order <- dim(coef)[3]
-     if (order==1)
+     fitdf <- dim(coef)[3]
+     if (fitdf==1)
        ans <- eigen(coef[,,1], symmetric=FALSE, only.values =TRUE)$value 
      else{
-        blockMat <- matrix(numeric((k*order)^2),k*order,k*order)
+        blockMat <- matrix(numeric((k*fitdf)^2),k*fitdf,k*fitdf)
         blockMat[1:k,] <- coef
-        Imat <- diag((order-1)*k)
-        blockMat[((k+1):(k*order)),1:((order-1)*k)] <- Imat
+        Imat <- diag((fitdf-1)*k)
+        blockMat[((k+1):(k*fitdf)),1:((fitdf-1)*k)] <- Imat
         ans <- eigen(blockMat, symmetric=FALSE, only.values =TRUE)$value 
      }
    MaxEigenvalue <- max(Mod(ans))
